# -*- coding: utf-8 -*-
#######
# actinia-core - an open source REST API for scalable, distributed, high
# performance processing of geographical data that uses GRASS GIS for
# computational tasks. For details, see https://actinia.mundialis.de/
#
# Copyright (c) 2016-2022 Sören Gebbert and mundialis GmbH & Co. KG
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#######

"""
API docs for resource_management
"""

from actinia_core.models.response_models import (
    ProcessingResponseListModel,
    ProcessingResponseModel,
    SimpleResponseModel,
)

__license__ = "GPLv3"
__author__ = "Sören Gebbert, Anika Weinmann"
__copyright__ = "Copyright 2016-2022, mundialis GmbH & Co. KG"
__maintainer__ = "mundialis GmbH & Co. KG"

resource_get_doc = {
    "tags": ["Resource Management"],
    "description": "Get the status of a resource. Minimum required user "
    "role: user.",
    "parameters": [
        {
            "name": "user_id",
            "description": "The unique user name/id",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "resource_id",
            "description": "The id of the resource",
            "required": True,
            "in": "path",
            "type": "string",
        },
    ],
    "responses": {
        "200": {
            "description": "The current state of the resource",
            "schema": ProcessingResponseModel,
        },
        "400": {
            "description": "The error message if the resource does not exists",
            "schema": SimpleResponseModel,
        },
    },
}

resource_put_doc = {
    "tags": ["Resource Management"],
    "description": "Updates/Resumes the status of a resource. "
    "Minimum required user role: user.",
    "parameters": [
        {
            "name": "user_id",
            "description": "The unique user name/id",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "resource_id",
            "description": "The id of the resource",
            "required": True,
            "in": "path",
            "type": "string",
        },
    ],
    "responses": {
        "200": {
            "description": "The current state of the resource",
            "schema": ProcessingResponseModel,
        },
        "400": {
            "description": "The error message if the resource does not exists",
            "schema": SimpleResponseModel,
        },
    },
}

resource_delete_doc = {
    "tags": ["Resource Management"],
    "description": "Request the termination of a resource. "
    "Minimum required user role: user.",
    "parameters": [
        {
            "name": "user_id",
            "description": "The unique user name/id",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "resource_id",
            "description": "The id of the resource",
            "required": True,
            "in": "path",
            "type": "string",
        },
    ],
    "responses": {
        "200": {
            "description": "Returned if termination request of the resource "
            "was successfully committed. "
            "Be aware that this does not mean, that the "
            "resource was successfully terminated.",
            "schema": SimpleResponseModel,
        },
        "400": {
            "description": "The error message why resource storage "
            "information gathering did not succeeded",
            "schema": SimpleResponseModel,
        },
    },
}

resources_get_doc = {
    "tags": ["Resource Management"],
    "description": "Get a list of resources that have been generated by the "
    "specified user. Minimum required user role: user.",
    "parameters": [
        {
            "name": "user_id",
            "description": "The unique user name/id",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "num",
            "description": "The maximum number of jobs that should be "
            "returned",
            "required": False,
            "in": "query",
            "type": "integer",
        },
        {
            "name": "type",
            "description": "The type of job that should be returned: "
            "accepted, running, error, terminated, finished",
            "required": False,
            "in": "query",
            "type": "string",
        },
    ],
    "responses": {
        "200": {
            "description": "Returned a list of resources that have been "
            "generated by the specified user.",
            "schema": ProcessingResponseListModel,
        },
        "401": {
            "description": "The error message why resource gathering did "
            "not succeeded",
            "schema": SimpleResponseModel,
        },
    },
}

resources_delete_doc = {
    "tags": ["Resource Management"],
    "description": "Terminate all accepted and running resources of the "
    "specified user. Minimum required user role: user.",
    "parameters": [
        {
            "name": "user_id",
            "description": "The unique user name/id",
            "required": True,
            "in": "path",
            "type": "string",
        }
    ],
    "responses": {
        "200": {
            "description": "Termination requests have been successfully "
            "committed. Be aware that does not mean, that "
            "the resources have been successfully terminated.",
            "schema": SimpleResponseModel,
        },
        "401": {
            "description": "The error message why the resource termination "
            "did not succeeded",
            "schema": SimpleResponseModel,
        },
    },
}

resource_iteration_get_doc = {
    "tags": ["Resource Iteration Management"],
    "description": "Get the status of a resource with the iterations. "
    "Minimum required user role: user.",
    "parameters": [
        {
            "name": "user_id",
            "description": "The unique user name/id",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "resource_id",
            "description": "The id of the resource",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "iteration",
            "description": "The id of the resource",
            "required": True,
            "in": "path",
            "type": "integer",
        },
    ],
    "responses": {
        "200": {
            "description": "The current state of the resource",
            "schema": ProcessingResponseModel,
        },
        "400": {
            "description": "The error message if the resource does not exists",
            "schema": SimpleResponseModel,
        },
    },
}



# -*- coding: utf-8 -*-
#######
# actinia-core - an open source REST API for scalable, distributed, high
# performance processing of geographical data that uses GRASS GIS for
# computational tasks. For details, see https://actinia.mundialis.de/
#
# Copyright (c) 2016-2022 Sören Gebbert and mundialis GmbH & Co. KG
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#######

"""
API docs for raster_export
"""

from actinia_core.models.response_models import (
    ProcessingResponseModel,
    ProcessingErrorResponseModel,
)

__license__ = "GPLv3"
__author__ = "Sören Gebbert, Anika Weinmann"
__copyright__ = "Copyright 2016-2022, mundialis GmbH & Co. KG"
__maintainer__ = "mundialis GmbH & Co. KG"

post_doc = {
    "tags": ["Raster Management"],
    "description": "Export an existing raster map layer as GTiff or COG "
    "(if COG driver available). The link to the exported "
    "raster map layer is located in the JSON response."
    "The current region settings of the mapset are used to "
    "export the raster layer. Minimum required user role: user.",
    "parameters": [
        {
            "name": "location_name",
            "description": "The location name",
            "required": True,
            "in": "path",
            "type": "string",
            "default": "nc_spm_08",
        },
        {
            "name": "mapset_name",
            "description": "The name of the mapset that contains the "
            "required raster map layer",
            "required": True,
            "in": "path",
            "type": "string",
            "default": "PERMANENT",
        },
        {
            "name": "raster_name",
            "description": "The name of the raster map layer to export",
            "required": True,
            "in": "path",
            "type": "string",
            "default": "elevation",
        },
    ],
    "consumes": ["application/json"],
    "produces": ["application/json"],
    "responses": {
        "200": {
            "description": "The response including the URL to the raster "
            "map layer GeoTiff file",
            "schema": ProcessingResponseModel,
        },
        "400": {
            "description": "The error message and a detailed log why"
            " gathering raster map layer information did "
            "not succeeded",
            "schema": ProcessingErrorResponseModel,
        },
    },
}

region_post_doc = {
    "tags": ["Raster Management"],
    "description": "Export an existing raster map layer as GTiff or COG "
    "(if COG driver available). The link to the exported "
    "raster map layer is located in the JSON response. "
    "Minimum required user role: user.",
    "parameters": [
        {
            "name": "location_name",
            "description": "The location name",
            "required": True,
            "in": "path",
            "type": "string",
            "default": "nc_spm_08",
        },
        {
            "name": "mapset_name",
            "description": "The name of the mapset that contains the "
            "required raster map layer",
            "required": True,
            "in": "path",
            "type": "string",
            "default": "PERMANENT",
        },
        {
            "name": "raster_name",
            "description": "The name of the raster map layer to export",
            "required": True,
            "in": "path",
            "type": "string",
            "default": "elevation",
        },
    ],
    "consumes": ["application/json"],
    "produces": ["application/json"],
    "responses": {
        "200": {
            "description": "The response including the URL to the raster "
            "map layer GeoTiff file",
            "schema": ProcessingResponseModel,
        },
        "400": {
            "description": "The error message and a detailed log why "
            "gathering raster map layer information did "
            "not succeeded",
            "schema": ProcessingErrorResponseModel,
        },
    },
}



# -*- coding: utf-8 -*-
#######
# actinia-core - an open source REST API for scalable, distributed, high
# performance processing of geographical data that uses GRASS GIS for
# computational tasks. For details, see https://actinia.mundialis.de/
#
# Copyright (c) 2016-2018 Sören Gebbert and mundialis GmbH & Co. KG
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#######

"""
Models for Raster colors management
"""

from flask_restful_swagger_2 import Schema

__license__ = "GPLv3"
__author__ = "Sören Gebbert, Carmen Tawalika"
__copyright__ = "Copyright 2016-2021, Sören Gebbert and mundialis GmbH & Co. KG"
__maintainer__ = "mundialis"


class RasterColorModel(Schema):
    """Response schema that is used in cases that no asynchronous run was performed.

    """
    description = "Set the color table for an existing raster map layer with a " \
                  "set of rules, a specific color or an other raster map layer"
    type = 'object'
    properties = {
        'rules': {
            'type': 'array',
            'description': 'A list of rules to set the color table of a raster '
                           'map layer',
            'items': {'type': "string"}
        },
        'color': {
            'type': 'string',
            'description': 'The name of a color to be set for a raster map layer'
        },
        'raster': {
            'type': 'string',
            'description': 'The name of an existing raster map layer to copy '
                           'the color table from'
        }
    }
    example = {
        "rules": ["1 0:0:0",
                  "default 255:255:255"],
        "color": "ndvi",
        "raster": "elevation@PERMANENT"
    }



# -*- coding: utf-8 -*-
#######
# actinia-core - an open source REST API for scalable, distributed, high
# performance processing of geographical data that uses GRASS GIS for
# computational tasks. For details, see https://actinia.mundialis.de/
#
# Copyright (c) 2016-2018 Sören Gebbert and mundialis GmbH & Co. KG
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#######

"""
STRDS raster map layer management

TODO: Integrate into the ephemeral process chain approach
"""
from copy import deepcopy
from flask_restful_swagger_2 import Schema
from actinia_core.models.response_models import \
    ProcessingResponseModel

__license__ = "GPLv3"
__author__ = "Sören Gebbert, Carmen Tawalika"
__copyright__ = "Copyright 2016-2021, Sören Gebbert and mundialis GmbH & Co. KG"
__maintainer__ = "mundialis"


class STRDSRasterListEntryModel(Schema):
    """Schema that contains list entry

    columns=id,start_time,end_time,north,south,east,west,min,max,rows,cols
    """
    description = "A single raster map layer information entry"
    type = 'object'
    properties = {
        'id': {'type': 'string'},
        'start_time': {'type': 'string'},
        'end_time': {'type': 'string'},
        'min': {'type': 'string'},
        'max': {'type': 'string'},
        'north': {'type': 'string'},
        'south': {'type': 'string'},
        'east': {'type': 'string'},
        'west': {'type': 'string'},
        'rows': {'type': 'string'},
        'cols': {'type': 'string'}
    }
    example = {
        "cols": "201",
        "east": "75.5",
        "end_time": "2013-06-01 00:00:00",
        "id": "precipitation_monthly_mm_760@PERMANENT",
        "max": "403.8",
        "min": "0.0",
        "north": "75.5",
        "rows": "464",
        "south": "25.25",
        "start_time": "2013-05-01 00:00:00",
        "west": "-40.5"
    }


class STRDSRasterListResponseModel(ProcessingResponseModel):
    """Response schema for STRDS raster map layer list information.
    """
    type = 'object'
    properties = deepcopy(ProcessingResponseModel.properties)
    properties["process_results"] = {}
    properties["process_results"]["type"] = "array"
    properties["process_results"]["items"] = STRDSRasterListEntryModel
    required = deepcopy(ProcessingResponseModel.required)
    # required.append("process_results")
    example = {
        "accept_datetime": "2018-05-06 21:28:18.583050",
        "accept_timestamp": 1525634898.5830483,
        "api_info": {
            "endpoint": "strdsrastermanagement",
            "method": "GET",
            "path": "/locations/ECAD/mapsets/PERMANENT/strds/"
                    "precipitation_1950_2013_yearly_mm/raster_layers",
            "request_url": "http://localhost:5000/locations/ECAD/mapsets/"
                           "PERMANENT/strds/precipitation_1950_2013_yearly_mm/"
                           "raster_layers?where=start_time>'2010-01-01'"
        },
        "datetime": "2018-05-06 21:28:19.187395",
        "http_code": 200,
        "message": "Processing successfully finished",
        "process_chain_list": [
            {
                "1": {
                    "flags": "u",
                    "inputs": {
                        "columns": "id,start_time,end_time,north,south,east,"
                                   "west,min,max,rows,cols",
                        "input": "precipitation_1950_2013_yearly_mm@PERMANENT",
                        "separator": "|",
                        "where": "start_time>'2010-01-01'"
                    },
                    "module": "t.rast.list",
                    "outputs": {
                        "output": {
                            "name": "/home/soeren/actinia/workspace/temp_db/"
                                    "gisdbase_1b72938d2ef54c199f6627b8720f21e1/"
                                    ".tmp/tmptps71vn7"
                        }
                    }
                }
            }
        ],
        "process_log": [
            {
                "executable": "t.rast.list",
                "parameter": [
                    "input=precipitation_1950_2013_yearly_mm@PERMANENT",
                    "where=start_time>'2010-01-01'",
                    "separator=|",
                    "columns=id,start_time,end_time,north,south,east,west,min,"
                    "max,rows,cols",
                    "output=/home/soeren/actinia/workspace/temp_db/"
                    "gisdbase_1b72938d2ef54c199f6627b8720f21e1/.tmp/tmptps71vn7",
                    "-u"
                ],
                "return_code": 0,
                "run_time": 0.5023984909057617,
                "stderr": [
                    ""
                ],
                "stdout": ""
            }
        ],
        "process_results": [
            {
                "cols": "201",
                "east": "75.5",
                "end_time": "2011-01-01 00:00:00",
                "id": "precipitation_yearly_mm_60@PERMANENT",
                "max": "2899.6",
                "min": "22.5",
                "north": "75.5",
                "rows": "464",
                "south": "25.25",
                "start_time": "2010-01-01 00:00:00",
                "west": "-40.5"
            },
            {
                "cols": "201",
                "east": "75.5",
                "end_time": "2012-01-01 00:00:00",
                "id": "precipitation_yearly_mm_61@PERMANENT",
                "max": "4226.0",
                "min": "10.0",
                "north": "75.5",
                "rows": "464",
                "south": "25.25",
                "start_time": "2011-01-01 00:00:00",
                "west": "-40.5"
            },
            {
                "cols": "201",
                "east": "75.5",
                "end_time": "2013-01-01 00:00:00",
                "id": "precipitation_yearly_mm_62@PERMANENT",
                "max": "3442.6",
                "min": "0.0",
                "north": "75.5",
                "rows": "464",
                "south": "25.25",
                "start_time": "2012-01-01 00:00:00",
                "west": "-40.5"
            }
        ],
        "progress": {
            "num_of_steps": 1,
            "step": 1
        },
        "resource_id": "resource_id-729ace44-6245-43c7-a875-d2059c1a1549",
        "status": "finished",
        "time_delta": 0.6043989658355713,
        "timestamp": 1525634899.1873734,
        "urls": {
            "resources": [],
            "status": "http://localhost:5000/resources/user/"
                      "resource_id-729ace44-6245-43c7-a875-d2059c1a1549"
        },
        "user_id": "user"
    }


class RasterListEntryModel(Schema):
    type = 'object'
    properties = {
        'name': {'type': 'string'},
        'start_time': {'type': 'string'},
        'end_time': {'type': 'string'}
    }


class RasterListRegisterModel(Schema):
    type = 'array'
    items = RasterListEntryModel
    example = [
        {
            "end_time": "2013-06-01 00:00:00",
            "start_time": "2013-05-01 00:00:00",
            "name": "precipitation_monthly_mm_760",
        },
        {
            "end_time": "2013-07-01 00:00:00",
            "start_time": "2013-06-01 00:00:00",
            "name": "precipitation_monthly_mm_761",
        }
    ]



# -*- coding: utf-8 -*-
#######
# actinia-core - an open source REST API for scalable, distributed, high
# performance processing of geographical data that uses GRASS GIS for
# computational tasks. For details, see https://actinia.mundialis.de/
#
# Copyright (c) 2016-2018 Sören Gebbert and mundialis GmbH & Co. KG
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#######

"""
Raster layer resources
"""
from copy import deepcopy
from flask_restful_swagger_2 import Schema
from actinia_core.models.response_models import ProcessingResponseModel

__license__ = "GPLv3"
__author__ = "Sören Gebbert, Carmen Tawalika"
__copyright__ = "Copyright 2016-2021, Sören Gebbert and mundialis GmbH & Co. KG"
__maintainer__ = "mundialis"


class RasterInfoModel(Schema):
    """Schema that contains raster map layer information
    """
    type = 'object'
    properties = {
        'cells': {'type': 'string'},
        'cols': {'type': 'string'},
        'comments': {'type': 'string'},
        'creator': {'type': 'string'},
        'database': {'type': 'string'},
        'datatype': {'type': 'string'},
        'maptype': {'type': 'string'},
        'east': {'type': 'string'},
        'date': {'type': 'string'},
        'description': {'type': 'string'},
        'ewres': {'type': 'string'},
        'max': {'type': 'string'},
        'min': {'type': 'string'},
        'ncats': {'type': 'string'},
        'nsres': {'type': 'string'},
        'location': {'type': 'string'},
        'map': {'type': 'string'},
        'mapset': {'type': 'string'},
        'rows': {'type': 'string'},
        'source1': {'type': 'string'},
        'north': {'type': 'string'},
        'source2': {'type': 'string'},
        'units': {'type': 'string'},
        'vdatum': {'type': 'string'},
        'south': {'type': 'string'},
        'timestamp': {'type': 'string'},
        'title': {'type': 'string'},
        'west': {'type': 'string'},
        'semantic_label': {'type': 'string'}
    }
    example = {
        "cells": "2025000",
        "cols": "1500",
        "comments": "\"r.proj input=\"ned03arcsec\" "
                    "location=\"northcarolina_latlong\" mapset=\"\\helena\" "
                    "output=\"elev_ned10m\" method=\"cubic\" resolution=10\"",
        "creator": "\"helena\"",
        "database": "/tmp/gisdbase_75bc0828",
        "datatype": "FCELL",
        "date": "\"Tue Nov  7 01:09:51 2006\"",
        "description": "\"generated by r.proj\"",
        "east": "645000",
        "ewres": "10",
        "location": "nc_spm_08",
        "map": "elevation",
        "mapset": "PERMANENT",
        "max": "156.3299",
        "min": "55.57879",
        "ncats": "255",
        "north": "228500",
        "nsres": "10",
        "rows": "1350",
        "source1": "\"\"",
        "source2": "\"\"",
        "south": "215000",
        "timestamp": "\"none\"",
        "title": "\"South-West Wake county: Elevation NED 10m\"",
        "units": "\"none\"",
        "vdatum": "\"none\"",
        "west": "630000"
    }


class RasterInfoResponseModel(ProcessingResponseModel):
    """Response schema for raster map layer information.
    """
    type = 'object'
    properties = deepcopy(ProcessingResponseModel.properties)
    properties["process_results"] = RasterInfoModel
    required = deepcopy(ProcessingResponseModel.required)
    # required.append("process_results")
    example = {
        "accept_datetime": "2018-05-02 10:44:11.764375",
        "accept_timestamp": 1525257851.7643716,
        "api_info": {
            "endpoint": "rasterlayerresource",
            "method": "GET",
            "path": "/locations/nc_spm_08/mapsets/PERMANENT/raster_layers/elevation",
            "request_url": "http://localhost:8080/locations/nc_spm_08/mapsets/"
                           "PERMANENT/raster_layers/elevation"
        },
        "datetime": "2018-05-02 10:44:11.897704",
        "http_code": 200,
        "message": "Processing successfully finished",
        "process_chain_list": [
            {
                "1": {
                    "flags": "gre",
                    "inputs": {
                        "map": "elevation@PERMANENT"
                    },
                    "module": "r.info"
                }
            }
        ],
        "process_log": [
            {
                "executable": "r.info",
                "parameter": [
                    "map=elevation@PERMANENT",
                    "-gre"
                ],
                "return_code": 0,
                "run_time": 0.050168514251708984,
                "stderr": [
                    ""
                ],
                "stdout": "..."}
        ],
        "process_results": {
            "cells": "2025000",
            "cols": "1500",
            "comments": "\"r.proj input=\"ned03arcsec\" "
                        "location=\"northcarolina_latlong\" mapset=\"\\helena\" "
                        "output=\"elev_ned10m\" method=\"cubic\" resolution=10\"",
            "creator": "\"helena\"",
            "database": "/actinia/workspace/temp_db/"
                        "gisdbase_5f1a5262c8bf4d4789348ffa2406ec3e",
            "datatype": "FCELL",
            "date": "\"Tue Nov  7 01:09:51 2006\"",
            "description": "\"generated by r.proj\"",
            "east": "645000",
            "ewres": "10",
            "location": "nc_spm_08",
            "map": "elevation",
            "mapset": "PERMANENT",
            "max": "156.3299",
            "min": "55.57879",
            "ncats": "255",
            "north": "228500",
            "nsres": "10",
            "rows": "1350",
            "source1": "\"\"",
            "source2": "\"\"",
            "south": "215000",
            "timestamp": "\"none\"",
            "title": "\"South-West Wake county: Elevation NED 10m\"",
            "units": "\"none\"",
            "vdatum": "\"none\"",
            "west": "630000"
        },
        "progress": {
            "num_of_steps": 1,
            "step": 1
        },
        "resource_id": "resource_id-0a3d6b2b-0962-4d01-8993-7997f15d1595",
        "status": "finished",
        "time_delta": 0.13338971138000488,
        "timestamp": 1525257851.8976946,
        "urls": {
            "resources": [],
            "status": "http://localhost:8080/resources/user/"
                      "resource_id-0a3d6b2b-0962-4d01-8993-7997f15d1595"
        },
        "user_id": "user"
    }



# -*- coding: utf-8 -*-
#######
# actinia-core - an open source REST API for scalable, distributed, high
# performance processing of geographical data that uses GRASS GIS for
# computational tasks. For details, see https://actinia.mundialis.de/
#
# Copyright (c) 2016-2022 Sören Gebbert and mundialis GmbH & Co. KG
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#######

"""
API docs for map_layer_management
"""

from actinia_core.models.response_models import (
    ProcessingResponseModel,
    StringListProcessingResultResponseModel,
)

__license__ = "GPLv3"
__author__ = "Sören Gebbert, Anika Weinmann"
__copyright__ = "Copyright 2016-2022, mundialis GmbH & Co. KG"
__maintainer__ = "mundialis GmbH & Co. KG"

raster_get_doc = {
    "tags": ["Raster Management"],
    "description": "Get a list of raster map layer names that are located "
    "in a specific location/mapset."
    " Minimum required user role: user.",
    "parameters": [
        {
            "name": "location_name",
            "description": "The name of the location that should be accessed",
            "required": True,
            "in": "path",
            "type": "string",
            "default": "nc_spm_08",
        },
        {
            "name": "mapset_name",
            "description": "The name of the mapset from which the raster "
            "map layers should be listed",
            "required": True,
            "in": "path",
            "type": "string",
            "default": "PERMANENT",
        },
        {
            "name": "pattern",
            "description": "A parameter passed to g.list for raster map"
            ' layer selection, eg.: http://<url>?pattern="*"',
            "required": False,
            "in": "query",
            "type": "string",
        },
    ],
    "responses": {
        "200": {
            "description": "This response returns a list of raster map layers "
            "and the log of the process chain that was used to "
            "create the response.",
            "schema": StringListProcessingResultResponseModel,
        },
        "400": {
            "description": "The error message and a detailed log why listing "
            "of raster map layers did not succeeded",
            "schema": ProcessingResponseModel,
        },
    },
}

raster_put_doc = {
    "tags": ["Raster Management"],
    "description": "Rename a single raster map layer or a list of raster "
    "map layers that are located in a specific location/mapset. "
    "Minimum required user role: user.",
    "parameters": [
        {
            "name": "location_name",
            "description": "The name of the location that should be accessed",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "mapset_name",
            "description": "The name of the mapset from which the raster "
            "map layers should be renamed",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "rename_list",
            "description": "A list of raster name tuples [(a, a_new),"
            "(b, b_new),(c, c_new), ...]",
            "required": True,
            "in": "body",
            "schema": {"type": "string"},
        },
    ],
    "responses": {
        "200": {
            "description": "This response returns the log of the process "
            "chain that was used to create the response.",
            "schema": ProcessingResponseModel,
        },
        "400": {
            "description": "The error message and a detailed log why listing "
            "of raster map layers did not succeeded",
            "schema": ProcessingResponseModel,
        },
    },
}

raster_delete_doc = {
    "tags": ["Raster Management"],
    "description": "Delete a single raster map layer or a list of raster "
    "map layer names that are located in a specific "
    "location/mapset. Minimum required user role: user.",
    "parameters": [
        {
            "name": "location_name",
            "description": "The name of the location that should be accessed",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "mapset_name",
            "description": "The name of the mapset from which the raster map "
            "layers should be deleted",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "pattern",
            "description": "A parameter passed for g.remove to remove a list "
            "of raster map layers, to remove all eg.: "
            'http://<url>?pattern="*"',
            "required": False,
            "in": "query",
            "type": "string",
        },
    ],
    "responses": {
        "200": {
            "description": "This response returns the log of the process chain"
            " that was used to create the response.",
            "schema": ProcessingResponseModel,
        },
        "400": {
            "description": "The error message and a detailed log why deletion "
            "of raster map layers did not succeeded",
            "schema": ProcessingResponseModel,
        },
    },
}

vector_get_doc = {
    "tags": ["Vector Management"],
    "description": "Get a list of vector map layer names that are located "
    "in a specific location/mapset."
    " Minimum required user role: user.",
    "parameters": [
        {
            "name": "location_name",
            "description": "The name of the location that should be accessed",
            "required": True,
            "in": "path",
            "type": "string",
            "default": "nc_spm_08",
        },
        {
            "name": "mapset_name",
            "description": "The name of the mapset from which the vector map "
            "layers should be listed",
            "required": True,
            "in": "path",
            "type": "string",
            "default": "PERMANENT",
        },
        {
            "name": "pattern",
            "description": "A parameter passed to g.list for vector map"
            ' layer selection, eg.: http://<url>?pattern="*"',
            "required": False,
            "in": "query",
            "type": "string",
        },
    ],
    "responses": {
        "200": {
            "description": "This response returns a list of vector map layers "
            "and the log of the process chain that was used "
            "to create the response.",
            "schema": StringListProcessingResultResponseModel,
        },
        "400": {
            "description": "The error message and a detailed log why listing "
            "of vector map layers did not succeeded",
            "schema": ProcessingResponseModel,
        },
    },
}

vector_put_doc = {
    "tags": ["Vector Management"],
    "description": "Rename a single vector map layer or a list of vector "
    "map layers that are located in a specific "
    "location/mapset. Minimum required user role: user.",
    "parameters": [
        {
            "name": "location_name",
            "description": "The name of the location that should be accessed",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "mapset_name",
            "description": "The name of the mapset from which the vector "
            "map layers should be renamed",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "rename_list",
            "description": "A list of vector name tuples [(a, a_new),"
            "(b, b_new),(c, c_new), ...]",
            "required": True,
            "in": "body",
            "schema": {"type": "string"},
        },
    ],
    "responses": {
        "200": {
            "description": "This response returns the log of the process chain"
            " that was used to create the response.",
            "schema": ProcessingResponseModel,
        },
        "400": {
            "description": "The error message and a detailed log why listing "
            "of vector map layers did not succeeded",
            "schema": ProcessingResponseModel,
        },
    },
}

vector_delete_doc = {
    "tags": ["Vector Management"],
    "description": "Delete a single vector map layer or a list of vector "
    "map layer names that are located in a specific "
    "location/mapset. Minimum required user role: user.",
    "parameters": [
        {
            "name": "location_name",
            "description": "The name of the location that should be accessed",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "mapset_name",
            "description": "The name of the mapset from which the vector "
            "map layers should be deleted",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "pattern",
            "description": "A parameter passed for g.remove to remove a "
            "list of vector map layers, to remove all eg.: "
            'http://<url>?pattern="*"',
            "required": False,
            "in": "query",
            "type": "string",
        },
    ],
    "responses": {
        "200": {
            "description": "This response returns the log "
            "of the process chain that was used to create "
            "the response.",
            "schema": ProcessingResponseModel,
        },
        "400": {
            "description": "The error message and a detailed log why deletion "
            "of vector map layers did not succeeded",
            "schema": ProcessingResponseModel,
        },
    },
}



# -*- coding: utf-8 -*-
#######
# actinia-core - an open source REST API for scalable, distributed, high
# performance processing of geographical data that uses GRASS GIS for
# computational tasks. For details, see https://actinia.mundialis.de/
#
# Copyright (c) 2016-2022 Sören Gebbert and mundialis GmbH & Co. KG
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#######

"""
API docs for user_api_key
"""

from actinia_api.swagger2.actinia_core.schemas.user_api_key import (
    TokenResponseModel,
)

__license__ = "GPLv3"
__author__ = "Sören Gebbert, Carmen Tawalika, Anika Weinmann"
__copyright__ = "Copyright 2016-2022, mundialis GmbH & Co. KG"
__maintainer__ = "mundialis GmbH & Co. KG"

apikey_get_doc = {
    "tags": ["Authentication Management"],
    "description": "Create an API key for permanent authentication. "
    "API keys have no expiration time. "
    "Minimum required user role: admin.",
    "responses": {
        "200": {
            "description": "The API key generation response",
            "schema": TokenResponseModel,
        },
        "400": {
            "description": "The error message in case of failure",
            "schema": TokenResponseModel,
        },
    },
}

token_get_doc = {
    "tags": ["Authentication Management"],
    "description": "Create an authentication token. Tokens have an "
    "expiration time. The default expiration time is one day "
    "(86400s). maximum length is 365 days. "
    "Minimum required user role: user.",
    "parameters": [
        {
            "name": "expiration_time",
            "description": "The expiration time in seconds for the generated "
            "token.",
            "required": False,
            "in": "query",
            "type": "integer",
            "default": 86400,
        }
    ],
    "responses": {
        "200": {
            "description": "The token generation response",
            "schema": TokenResponseModel,
        },
        "400": {
            "description": "The error message in case of failure",
            "schema": TokenResponseModel,
        },
    },
}



# -*- coding: utf-8 -*-
#######
# actinia-core - an open source REST API for scalable, distributed, high
# performance processing of geographical data that uses GRASS GIS for
# computational tasks. For details, see https://actinia.mundialis.de/
#
# Copyright (c) 2016-2022 Sören Gebbert and mundialis GmbH & Co. KG
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#######

"""
API docs for strds_management
"""

from actinia_core.models.response_models import (
    ProcessingErrorResponseModel,
    ProcessingResponseModel,
    StringListProcessingResultResponseModel,
)

from actinia_api.swagger2.actinia_core.schemas.strds_management import (
    STRDSCreationModel,
    STRDSInfoResponseModel,
)

__license__ = "GPLv3"
__author__ = "Sören Gebbert, Carmen Tawalika, Anika Weinmann"
__copyright__ = "Copyright 2016-2022, mundialis GmbH & Co. KG"
__maintainer__ = "mundialis GmbH & Co. KG"

list_get_doc = {
    "tags": ["STRDS Management"],
    "description": "Get a list of all STRDS that are located in a specific "
    "location/mapset. Minimum required user role: user.",
    "parameters": [
        {
            "name": "location_name",
            "description": "The name of the location",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "mapset_name",
            "description": "The name of the mapset",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "where",
            "description": "A where statement to select user specific STRDS",
            "required": False,
            "in": "query",
            "type": "string",
        },
    ],
    "responses": {
        "200": {
            "description": "This response returns a list of STRDS names and "
            "timestamps and the log of the process chain "
            "that was used to create the response.",
            "schema": StringListProcessingResultResponseModel,
        },
        "400": {
            "description": "The error message and a detailed log why listing "
            "of STRDS did not succeeded",
            "schema": ProcessingErrorResponseModel,
        },
    },
}

get_doc = {
    "tags": ["STRDS Management"],
    "description": "Get information about a STRDS that is located in a "
    "specific location/mapset. "
    "Minimum required user role: user.",
    "parameters": [
        {
            "name": "location_name",
            "description": "The name of the location",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "mapset_name",
            "description": "The name of the mapset",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "strds_name",
            "description": "The name of the STRDS",
            "required": True,
            "in": "path",
            "type": "string",
        },
    ],
    "responses": {
        "200": {
            "description": "This response returns information about a "
            "specific STRDS and the log of the process chain "
            "that was used to create the response.",
            "schema": STRDSInfoResponseModel,
        },
        "400": {
            "description": "The error message and a detailed log why "
            "information gathering of the STRDS did not succeeded",
            "schema": ProcessingErrorResponseModel,
        },
    },
}

delete_doc = {
    "tags": ["STRDS Management"],
    "description": "Delete a STRDS that is located in a specific location/"
    "mapset. Minimum required user role: user.",
    "parameters": [
        {
            "name": "location_name",
            "description": "The name of the location",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "mapset_name",
            "description": "The name of the mapset",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "strds_name",
            "description": "The name of the STRDS",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "recursive",
            "description": "Delete the STRDS and all registered raster map "
            "layer recursively",
            "required": False,
            "in": "query",
            "type": "boolean",
        },
    ],
    "responses": {
        "200": {
            "description": "Deletion of the STRDS was successfully finished.",
            "schema": ProcessingResponseModel,
        },
        "400": {
            "description": "The error message and a detailed log why "
            "deletion of the STRDS did not succeeded",
            "schema": ProcessingErrorResponseModel,
        },
    },
}

post_doc = {
    "tags": ["STRDS Management"],
    "description": "Create a new STRDS in a specific location/mapset. "
    "Minimum required user role: user.",
    "parameters": [
        {
            "name": "location_name",
            "description": "The name of the location",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "mapset_name",
            "description": "The name of the mapset",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "strds_name",
            "description": "The name of the STRDS",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "metadata",
            "description": "Temporal type, title and description of the STRDS",
            "required": True,
            "in": "body",
            "schema": STRDSCreationModel,
        },
    ],
    "responses": {
        "200": {
            "description": "Creation of the STRDS was successfully finished.",
            "schema": ProcessingResponseModel,
        },
        "400": {
            "description": "The error message and a detailed log why "
            "creation of the STRDS did not succeeded",
            "schema": ProcessingErrorResponseModel,
        },
    },
}



# -*- coding: utf-8 -*-
#######
# actinia-core - an open source REST API for scalable, distributed, high
# performance processing of geographical data that uses GRASS GIS for
# computational tasks. For details, see https://actinia.mundialis.de/
#
# Copyright (c) 2016-2022 Sören Gebbert and mundialis GmbH & Co. KG
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#######

"""
API docs for ephemeral_processing
"""

from actinia_core.core.common.process_chain import ProcessChainModel
from actinia_core.models.response_models import ProcessingResponseModel

__license__ = "GPLv3"
__author__ = "Sören Gebbert, Guido Riembauer, Anika Weinmann"
__copyright__ = "Copyright 2016-2022, mundialis GmbH & Co. KG"
__maintainer__ = "mundialis GmbH & Co. KG"

DESCR = """Execute a user defined process chain in an existing mapset
of the persistent user database or in a new mapset that will be
created by this request in the persistent user database.

The process chain is executed asynchronously. The provided status URL
in the response must be polled to gain information about the processing
progress and finishing status.

**Note**

    Space-time dataset processing can only be performed in a new mapset
    that is created by this resource call, since merging of temporal databases
    of different mapsets is not supported yet.

The mapset that is used for processing will be locked until the process
chain execution finished (successfully or not), even if the mapset is be
created by the request.
Other requests on the locked mapset will abort with a mapset lock error.

The persistent user database will not be modified if
the process chain does not run successfully. The processing is performed in an
ephemeral database and then merged or copied into the persistent user database.

**Note**

    Make sure that the process chain definition identifies all raster, vector
    or space time datasets correctly with name and mapset: name@mapset.

    All required mapsets will be identified by analysing the input parameter
    of all module descriptions in the provided process chain
    and mounted into the ephemeral database that is used for processing.

"""

post_doc = {
    "tags": ["Processing"],
    "description": DESCR,
    "consumes": ["application/json"],
    "parameters": [
        {
            "name": "location_name",
            "description": "The location name",
            "required": True,
            "in": "path",
            "type": "string",
            "default": "nc_spm_08",
        },
        {
            "name": "mapset_name",
            "description": "The name of an existing mapset or a new mapset "
            "that should be created",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "process_chain",
            "description": "The process chain that should be executed",
            "required": True,
            "in": "body",
            "schema": ProcessChainModel,
        },
    ],
    "responses": {
        "200": {
            "description": "The result of the process chain execution",
            "schema": ProcessingResponseModel,
        },
        "400": {
            "description": "The error message and a detailed log why process "
            "chain execution did not succeed",
            "schema": ProcessingResponseModel,
        },
    },
}



# -*- coding: utf-8 -*-
#######
# actinia-core - an open source REST API for scalable, distributed, high
# performance processing of geographical data that uses GRASS GIS for
# computational tasks. For details, see https://actinia.mundialis.de/
#
# Copyright (c) 2016-2022 Sören Gebbert and mundialis GmbH & Co. KG
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#######

"""
API docs for location_management
"""

from actinia_core.models.response_models import (
    MapsetInfoResponseModel,
    ProcessingResponseModel,
    SimpleResponseModel,
)
from actinia_api.swagger2.actinia_core.schemas.location_management import (
    LocationListResponseModel,
)
from actinia_api.swagger2.actinia_core.schemas.location_management import (
    ProjectionInfoModel,
)

__license__ = "GPLv3"
__author__ = "Sören Gebbert, Carmen Tawalika, Anika Weinmann"
__copyright__ = "Copyright 2016-2022, mundialis GmbH & Co. KG"
__maintainer__ = "mundialis GmbH & Co. KG"

get_doc = {
    "tags": ["Location Management"],
    "description": "Get a list of all available locations that are located in "
    "the GRASS database and the user has access to. Minimum required "
    "user role: user.",
    "responses": {
        "200": {
            "description": "This response returns a list of location names",
            "schema": LocationListResponseModel,
        },
        "400": {
            "description": "The error message",
            "schema": SimpleResponseModel,
        },
    },
}

get_user_doc = {
    "tags": ["Location Management"],
    "description": "Get the location projection and current computational "
    "region of the PERMANENT mapset. Minimum required user "
    "role: user.",
    "parameters": [
        {
            "name": "location_name",
            "description": "The name of the location",
            "required": True,
            "in": "path",
            "type": "string",
            "default": "nc_spm_08",
        }
    ],
    "responses": {
        "200": {
            "description": "The location projection and current computational "
            "region of the PERMANENT mapset",
            "schema": MapsetInfoResponseModel,
        },
        "400": {
            "description": "The error message",
            "schema": ProcessingResponseModel,
        },
    },
}

delete_admin_doc = {
    "tags": ["Location Management"],
    "description": "Delete an existing location and everything inside from the"
    " user database. Minimum required user role: admin.",
    "parameters": [
        {
            "name": "location_name",
            "description": "The name of the location to be deleted",
            "required": True,
            "in": "path",
            "type": "string",
        }
    ],
    "responses": {
        "200": {
            "description": "Success message for location deletion",
            "schema": SimpleResponseModel,
        },
        "400": {
            "description": "The error message",
            "schema": SimpleResponseModel,
        },
    },
}

post_admin_doc = {
    "tags": ["Location Management"],
    "description": "Create a new location based on EPSG code in the user "
    "database. Minimum required user role: admin.",
    "consumes": ["application/json"],
    "parameters": [
        {
            "name": "location_name",
            "description": "The name of the location to be created",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "epsg_code",
            "description": "The EPSG code",
            "required": True,
            "in": "body",
            "schema": ProjectionInfoModel,
        },
    ],
    "responses": {
        "200": {
            "description": "Create a new location based on EPSG code",
            "schema": ProcessingResponseModel,
        },
        "400": {
            "description": "The error message",
            "schema": ProcessingResponseModel,
        },
    },
}



# -*- coding: utf-8 -*-
#######
# actinia-core - an open source REST API for scalable, distributed, high
# performance processing of geographical data that uses GRASS GIS for
# computational tasks. For details, see https://actinia.mundialis.de/
#
# Copyright (c) 2016-2022 Sören Gebbert and mundialis GmbH & Co. KG
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#######

"""
API docs for raster_colors
"""

from actinia_core.models.response_models import (
    ProcessingResponseModel,
    ProcessingErrorResponseModel,
    StringListProcessingResultResponseModel,
)

from actinia_api.swagger2.actinia_core.schemas.raster_colors import (
    RasterColorModel,
)

__license__ = "GPLv3"
__author__ = "Sören Gebbert, Carmen Tawalika, Anika Weinmann"
__copyright__ = "Copyright 2016-2022, mundialis GmbH & Co. KG"
__maintainer__ = "mundialis GmbH & Co. KG"

get_doc = {
    "tags": ["Raster Management"],
    "description": "Get the color definition of an existing raster map layer. "
    "Minimum required user role: user.",
    "parameters": [
        {
            "name": "location_name",
            "description": "The location name",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "mapset_name",
            "description": "The name of the mapset that contains the "
            "required raster map layer",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "raster_name",
            "description": "The name of the raster map layer to get the "
            "color table from",
            "required": True,
            "in": "path",
            "type": "string",
        },
    ],
    "produces": ["application/json"],
    "responses": {
        "200": {
            "description": "A list of color rules",
            "schema": StringListProcessingResultResponseModel,
        },
        "400": {
            "description": "The error message and a detailed error log",
            "schema": ProcessingErrorResponseModel,
        },
    },
}


post_doc = {
    "tags": ["Raster Management"],
    "description": "Set the color definition for an existing raster map "
    "layer. Minimum required user role: user.",
    "parameters": [
        {
            "name": "location_name",
            "description": "The location name",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "mapset_name",
            "description": "The name of the mapset that contains the "
            "required raster map layer",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "raster_name",
            "description": "The name of the raster map layer to set the "
            "color table",
            "required": True,
            "in": "path",
            "type": "string",
        },
        {
            "name": "color",
            "description": "The color definition.",
            "required": True,
            "in": "body",
            "schema": RasterColorModel,
        },
    ],
    "produces": ["application/json"],
    "consumes": ["application/json"],
    "responses": {
        "200": {
            "description": "Successfuly set the color table for a raster map "
            "layer",
            "schema": ProcessingResponseModel,
        },
        "400": {
            "description": "The error message and a detailed error log",
            "schema": ProcessingErrorResponseModel,
        },
    },
}
